mxr_device

Function mxr_device 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn mxr_device( remote: *const mxr_remote_t, uid: mxr_uid_t, out: *mut mxr_device_info_t, ) -> mxr_result_t
Fills out with what is known about a device.

Safety

remote is null or a live handle, and out points at a writable mxr_device_info_t.